function varargout = power_analyze(varargin)
% POWER_ANALYZE  Analyze a circuit built with SimPowerSystems.
%
%    SPS = POWER_ANALYZE('SYS','structure') creates a structure array with 
%    fields and values describing the SimPowerSystems diagram 'SYS'.
%
%    SPS = POWER_ANALYZE('SYS','sort') return a structure array with specific 
%    fields related to the interconnection of SimPowerSystems blocks. 
%    
%    [A,B,C,D,x0,STATES,INPUTS,OUTPUTS,USS,XSS,YSS,FREQYSS,HLIN] = 
%    POWER_ANALYZE('SYS') computes the equivalent state-space model and returns 
%    the information into separate variables.
%
%    POWER_ANALYZE('SYS','net') generates a netlist stored in a file SYS.net.
%    This file contains the node numbers generated by POWER_ANALYZE, parameter
%    values of all linear elements and switches, as well as the list of outputs.
%
%    If you have the Control System Toolbox installed, SPS = POWER_ANALYZE('SYS','ss') 
%    creates a continuous state-space model of 'SYS'. The output SPS is a SS object.
%
%    SPS = POWER_ANALYZE('SYS','detailed') returns a more detailed structure
%    with internal data informations.    
%
%    See also POWER_STATESPACE

%   Patrice Brunelle, 01-07-98, 15-10-2002.
%   Copyright 1997-2004 TransEnergie Technologies Inc., under sublicense
%   from Hydro-Quebec, and The MathWorks, Inc.
%   $Revision: 1.1.6.3 $

if nargout == 0,
  power_analyze_pr(varargin{:});
else
  [varargout{1:nargout}] = power_analyze_pr(varargin{:});
end